==> 0.11.3.tar.gz: lib/src/descriptor_builders/bitbucket_impl.dart <==
library ac_dart.descriptor.builder.bitbucket.impl;

import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'package:atlassian_connect_shelf/src/descriptor_builders/standard_impl.dart';
import 'package:mojito/mojito.dart';
import 'package:atlassian_connect_shelf/src/descriptor_builders/bitbucket.dart';

import 'package:constrain/constrain.dart';
import 'package:logging/logging.dart';
import 'package:atlassian_connect_host/src/descriptor/bitbucket/scopes.dart';

final Validator _validator = new Validator();

Logger _log = new Logger('ac_dart.descriptor.builder.bitbucket.impl');

class BitbucketDescriptorBuilderImpl extends StandardDescriptorBuilderImpl<
    BitbucketModuleList,
    BitbucketScope,
    BitbucketConnectAddon> implements BitbucketDescriptorBuilder {
//  final List<Page> _repoPages = [];

  BitbucketDescriptorBuilderImpl(String addonKey, Uri baseUrl)
      : super(addonKey, baseUrl);

  BitbucketConnectAddon build(DefaultRouter rootRouter, Vendor vendor,
      {String name,
      String description,
      ClientId oauthClientId,
      Iterable<BitbucketScope> scopes}) {
    final addon = new BitbucketConnectAddon(
        key: addonKey,
        name: name,
        description: description,
        baseUrl: baseUrl,
        authentication:
            new Authentication(type: AuthenticationType.JWT), // TODO
        modules: buildModules(rootRouter, new Option(oauthClientId)),
        lifecycle: buildLifecycle(rootRouter),
        vendor: vendor,
        scopes: scopes);

    final constraints = _validator.validate(addon);

    if (constraints.isNotEmpty) {
      _log.severe('addon descriptor is invalid: $constraints');
    }

    return addon;
  }

  @override
  BitbucketModuleList buildProductModules(
      Iterable<ClassifiedModule> coreModules, DefaultRouter rootRouter) {
    return new BitbucketModuleList.fromModules(coreModules);
  }

  @override
  void addRepoPage(String key, String name, BitbucketLocation location) {
    addPage(BitbucketModuleTypes.repoPage, key, name, location);
  }
}

==> 0.11.6.tar.gz: lib/src/descriptor_builders/bitbucket_impl.dart <==
library ac_dart.descriptor.builder.bitbucket.impl;

import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'package:atlassian_connect_shelf/src/descriptor_builders/bitbucket.dart';
import 'package:atlassian_connect_shelf/src/descriptor_builders/standard_impl.dart';
import 'package:constrain/constrain.dart';
import 'package:logging/logging.dart';
import 'package:mojito/mojito.dart';

final Validator _validator = new Validator();

Logger _log = new Logger('ac_dart.descriptor.builder.bitbucket.impl');

class BitbucketDescriptorBuilderImpl extends StandardDescriptorBuilderImpl<
    BitbucketModuleList,
    BitbucketScope,
    BitbucketConnectAddon> implements BitbucketDescriptorBuilder {
//  final List<Page> _repoPages = [];

  BitbucketDescriptorBuilderImpl(String addonKey, Uri baseUrl)
      : super(addonKey, baseUrl, useAbsoluteUrls: true);

  BitbucketConnectAddon build(DefaultRouter rootRouter, Vendor vendor,
      {String name,
      String description,
      ClientId oauthClientId,
      Iterable<BitbucketScope> scopes}) {
    final addon = new BitbucketConnectAddon(
        key: addonKey,
        name: name,
        description: description,
        baseUrl: baseUrl,
        authentication:
            new Authentication(type: AuthenticationType.JWT), // TODO
        modules: buildModules(rootRouter, new Option(oauthClientId)),
        lifecycle: buildLifecycle(rootRouter),
        vendor: vendor,
        scopes: scopes);

    final constraints = _validator.validate(addon);

    if (constraints.isNotEmpty) {
      _log.severe('addon descriptor is invalid: $constraints');
    }

    return addon;
  }

  @override
  BitbucketModuleList buildProductModules(
      Iterable<ClassifiedModule> coreModules, DefaultRouter rootRouter) {
    return new BitbucketModuleList.fromModules(coreModules);
  }

  @override
  void addRepoPage(String key, String name, BitbucketLocation location) {
    addPage(BitbucketModuleTypes.repoPage, key, name, location);
  }
}
